summaryrefslogtreecommitdiffstats
path: root/src/pinyin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/pinyin.h')
-rw-r--r--src/pinyin.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/pinyin.h b/src/pinyin.h
index 1b2e5ea..6c45a26 100644
--- a/src/pinyin.h
+++ b/src/pinyin.h
@@ -228,16 +228,16 @@ bool pinyin_set_double_pinyin_scheme(pinyin_context_t * context,
DoublePinyinScheme scheme);
/**
- * pinyin_set_chewing_scheme:
+ * pinyin_set_zhuyin_scheme:
* @context: the pinyin context.
* @scheme: the chewing scheme.
* @returns: whether the set chewing scheme succeeded.
*
* Change the chewing scheme of the pinyin context.
*
*/
-bool pinyin_set_chewing_scheme(pinyin_context_t * context,
- ChewingScheme scheme);
+bool pinyin_set_zhuyin_scheme(pinyin_context_t * context,
+ ZhuyinScheme scheme);
/**
* pinyin_fini:
@@ -228,16 +228,16 @@ bool pinyin_set_double_pinyin_scheme(pinyin_context_t * context,
* @context: the pinyin context.
- * @scheme: the chewing scheme.
- * @returns: whether the set chewing scheme succeeded.
+ * @scheme: the zhuyin scheme.
+ * @returns: whether the set zhuyin scheme succeeded.
*
@@ -228,16 +228,16 @@ bool pinyin_set_double_pinyin_scheme(pinyin_context_t * context,
*
- * Change the chewing scheme of the pinyin context.
+ * Change the zhuyin scheme of the pinyin context.
*
*/